@@ -7,8 +7,7 @@ CREDENTIALS_PATH = PROJECT_PATH
 def test_get_video_details_01():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
-    video_id = easy_wrapper.extract_video_id(url='https://www.youtube.com/watch?v=LsK-xG1cLYA')
-    metadata = easy_wrapper.get_video_details(video_id=video_id)
+    metadata = easy_wrapper.get_video_details(video_id='LsK-xG1cLY')
     assert metadata['comments'][0] == 'Your channel has saved me a looooooot of time. Thanks!'
 
 
@@ -23,7 +22,10 @@ def test_search_videos_by_keyword():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
     search_keyword = 'python'
-    results = easy_wrapper.search_videos_by_keywords(q=search_keyword, part='id,snippet', type='video', order='relevance')
+    results = easy_wrapper.search_videos_by_keywords(q=search_keyword,
+                                                     part='id,snippet',
+                                                     type='video',
+                                                     order='relevance')
     order_id = 1
     video_id = results[order_id]['video_id']
     assert video_id == '_uQrJ0TkZlc'
